Security Policy
===============

Supported Versions
------------------

Security fixes will be released as a new version. Since the API is relatively stable and this is a small project, we release security fixes in new releases.

Reporting a Vulnerability
-------------------------

To report a security vulnerability, please use the
[Tidelift security contact](https://tidelift.com/security).
Tidelift will coordinate the fix and disclosure.
